.. _sec_advanced_scripting:

==============
Advanced Usage
==============
This section motivates the design of dclab and highlights useful built-in
functionalities.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   sec_av_notation
   sec_av_dc_usage
   sec_av_dc_io
   sec_av_basins/index
   sec_av_feat_plugin
   sec_av_feat_temp
   sec_av_scatter
   sec_av_fluorescence
   sec_av_emodulus/index
   sec_av_lme4
   sec_av_dcor
   sec_av_s3
